==> ejc-zhengyuan-impl-3.0.0-20241227.024427-13-sources.jar: com/ejianc/business/sq/keyan/vo/KeyanTechnicalTandardVO.java <==
package com.ejianc.business.sq.keyan.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;


/**
 * 技术标准
 * 
 * @author generator
 * 
 */
public class KeyanTechnicalTandardVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer billState; // 单据审批状态
    private String billCode; // 单据编码
    private Long unitId; // 所属单位id
    private String unitName; // 所属单位名称
    private String tandardNo; // 标准号
    private String tandardName; // 标准名称
    private String tandardCategory; // 标准类别
    private String participateForm; // 参与形式
    private String publishUnit; // 发布单位
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date publishTime; // 发布时间
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date implementationTime; // 实施时间
    private String managementDepartment; // 标准归口管理部门
    private String generalSystemDrafter; // 总局系统参编起草人员
    private String generalSystemUnitName; // 总局系统参编单位名称
    private String remarks; // 备注

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getUnitId() {
        return unitId;
    }

    @ReferDeserialTransfer
    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getTandardNo() {
        return tandardNo;
    }

    public void setTandardNo(String tandardNo) {
        this.tandardNo = tandardNo;
    }
    public String getTandardName() {
        return tandardName;
    }

    public void setTandardName(String tandardName) {
        this.tandardName = tandardName;
    }
    public String getTandardCategory() {
        return tandardCategory;
    }

    public void setTandardCategory(String tandardCategory) {
        this.tandardCategory = tandardCategory;
    }
    public String getParticipateForm() {
        return participateForm;
    }

    public void setParticipateForm(String participateForm) {
        this.participateForm = participateForm;
    }
    public String getPublishUnit() {
        return publishUnit;
    }

    public void setPublishUnit(String publishUnit) {
        this.publishUnit = publishUnit;
    }
    public Date getPublishTime() {
        return publishTime;
    }

    public void setPublishTime(Date publishTime) {
        this.publishTime = publishTime;
    }
    public Date getImplementationTime() {
        return implementationTime;
    }

    public void setImplementationTime(Date implementationTime) {
        this.implementationTime = implementationTime;
    }
    public String getManagementDepartment() {
        return managementDepartment;
    }

    public void setManagementDepartment(String managementDepartment) {
        this.managementDepartment = managementDepartment;
    }
    public String getGeneralSystemDrafter() {
        return generalSystemDrafter;
    }

    public void setGeneralSystemDrafter(String generalSystemDrafter) {
        this.generalSystemDrafter = generalSystemDrafter;
    }
    public String getGeneralSystemUnitName() {
        return generalSystemUnitName;
    }

    public void setGeneralSystemUnitName(String generalSystemUnitName) {
        this.generalSystemUnitName = generalSystemUnitName;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    
}

==> ejc-zhengyuan-impl-3.0.0-20250821.081133-43-sources.jar: com/ejianc/business/sq/keyan/vo/KeyanTechnicalTandardVO.java <==
package com.ejianc.business.sq.keyan.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;


/**
 * 技术标准
 * 
 * @author generator
 * 
 */
public class KeyanTechnicalTandardVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer billState; // 单据审批状态
    private String billCode; // 单据编码
    private Long unitId; // 所属单位id
    private String unitName; // 所属单位名称
    private String tandardNo; // 标准号
    private String tandardName; // 标准名称
    private String tandardCategory; // 标准类别
    private String participateForm; // 参与形式
    private String publishUnit; // 发布单位
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date publishTime; // 发布时间
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date implementationTime; // 实施时间
    private String managementDepartment; // 标准归口管理部门
    private String generalSystemDrafter; // 总局系统参编起草人员
    private String generalSystemUnitName; // 总局系统参编单位名称
    private String remarks; // 备注

    private String errorMsg; // 导入错误信息

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getUnitId() {
        return unitId;
    }

    @ReferDeserialTransfer
    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getTandardNo() {
        return tandardNo;
    }

    public void setTandardNo(String tandardNo) {
        this.tandardNo = tandardNo;
    }
    public String getTandardName() {
        return tandardName;
    }

    public void setTandardName(String tandardName) {
        this.tandardName = tandardName;
    }
    public String getTandardCategory() {
        return tandardCategory;
    }

    public void setTandardCategory(String tandardCategory) {
        this.tandardCategory = tandardCategory;
    }
    public String getParticipateForm() {
        return participateForm;
    }

    public void setParticipateForm(String participateForm) {
        this.participateForm = participateForm;
    }
    public String getPublishUnit() {
        return publishUnit;
    }

    public void setPublishUnit(String publishUnit) {
        this.publishUnit = publishUnit;
    }
    public Date getPublishTime() {
        return publishTime;
    }

    public void setPublishTime(Date publishTime) {
        this.publishTime = publishTime;
    }
    public Date getImplementationTime() {
        return implementationTime;
    }

    public void setImplementationTime(Date implementationTime) {
        this.implementationTime = implementationTime;
    }
    public String getManagementDepartment() {
        return managementDepartment;
    }

    public void setManagementDepartment(String managementDepartment) {
        this.managementDepartment = managementDepartment;
    }
    public String getGeneralSystemDrafter() {
        return generalSystemDrafter;
    }

    public void setGeneralSystemDrafter(String generalSystemDrafter) {
        this.generalSystemDrafter = generalSystemDrafter;
    }
    public String getGeneralSystemUnitName() {
        return generalSystemUnitName;
    }

    public void setGeneralSystemUnitName(String generalSystemUnitName) {
        this.generalSystemUnitName = generalSystemUnitName;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }
    
}
